# This code is copyrighted by iuveno AG in June, 2001.
#
# It is Open Source. See the LICENSE.txt for more details!
#
# written by Stephan Richter
# Last updated: July 3, 2001

import OrderedObjectManager, Globals
from AccessControl import getSecurityManager, ClassSecurityInfo
from Globals           import DTMLFile
from OFS import Folder

manage_addOrderedFolderForm = Globals.DTMLFile('dtml/folderAdd', globals())

def manage_addOrderedFolder(self, id, title='',
                            createPublic=0,
                            createUserF=0,
                            _is_transparent=0,
                            REQUEST=None):
    """Add a new OrderedFolder object with id *id*.

    If the 'createPublic' and 'createUserF' parameters are set to any true
    value, an 'index_html' and a 'UserFolder' objects are created respectively
    in the new folder.
    """
    ob=OrderedFolder()
    ob.id=str(id)
    ob.title=title
    ob._is_transparent=_is_transparent
    self._setObject(id, ob)
    ob=self._getOb(id)

    checkPermission=getSecurityManager().checkPermission    

    if createUserF:
        if not checkPermission('Add User Folders', ob):
            raise 'Unauthorized', (
                  'You are not authorized to add User Folders.'
                  )
        ob.manage_addUserFolder()

    if createPublic:
        if not checkPermission('Add Documents, Images, and Files', ob):
            raise 'Unauthorized', (
                  'You are not authorized to add DTML Documents.'
                  )
        ob.manage_addDTMLDocument(id='index_html', title='')

    if REQUEST is not None:
        return self.manage_main(self, REQUEST, update_menu=1)


from SubObjectTypeSupport import SubObjectTypeSupport
from TransparencySupport  import TransparencySupport
from MaxItemsSupport      import MaxItemsSupport

try:
    from LocalizationSupport  import LocalizationSupport
except:
    class LocalizationSupport:
        pass


class OrderedFolder(TransparencySupport, OrderedObjectManager.OrderedObjectManager,
                    MaxItemsSupport, LocalizationSupport, Folder.Folder):
    '''OrderedFolder class - Use the OrderedObjectManager and some other nice enhancements.'''
    meta_type = 'Ordered Folder'

#    security.declareProtected('View management screens','manage_subObjectTypes')    
#    manage_subObjectTypes = DTMLFile('dtml/subObjectTypes', globals())

#    manage_options = Folder.Folder.manage_options + ( {'label':'Sub-Objects', 'action':'manage_subObjectTypes',}, )

    manage_options = Folder.Folder.manage_options + SubObjectTypeSupport.manage_options

    security = ClassSecurityInfo()

    _properties = Folder.Folder._properties + TransparencySupport._properties + MaxItemsSupport._properties
  

Globals.default__class_init__(OrderedFolder)
